@@ -8,6 +8,8 @@ use urpm::util;
 use urpm::msg;
 use POSIX ();
 
+(our $VERSION) = q($Revision: 271299 $) =~ /(\d+)/;
+
 
 =head1 NAME
 
@@ -31,7 +33,9 @@ typically from the inst.list or skip.list files.
 sub get_packages_list {
     my ($file, $o_extra) = @_;
     my @l = split(/,/, $o_extra || '');
-    push @l, cat_($file);
+    if ($file && open(my $f, '<', $file)) {
+	push @l, <$f>;
+    }
     [ grep { $_ } map {
 	chomp; s/#.*$//; s/^\s*//; s/\s*$//;
 	$_;
@@ -63,6 +67,16 @@ sub find_a_mntpoint {
     _find_a_mntpoint($dir, {});
 }
 
+# deprecated
+sub find_mntpoints {
+    my ($dir, $infos) = @_;
+    if (my $entry = _find_a_mntpoint($dir, $infos)) {
+	$entry->{mntpoint};
+    } else {
+	();
+    }
+}
+
 sub read_mtab() { _read_fstab_or_mtab('/etc/mtab') }
 
 #- find used mount point from a pathname
@@ -191,7 +205,7 @@ sub trim_until_d {
 
 =item check_fs_writable()
 
-Checks if the main filesystems are writable for urpmi to install files in
+Checks if the main filesystems are writeable for urpmi to install files in
 
 =cut
 
